<template>
  <a-card :bordered="false">
    <!-- 查询区域 -->
    <div class="table-page-search-wrapper">
      <a-form layout="inline" @keyup.enter.native="searchQuery">
        <a-row :gutter="24">
        </a-row>
      </a-form>
    </div>
    <!-- 查询区域-END -->

    <!-- 操作按钮区域 -->
    <div class="table-operator" v-if="this.workCenterId">
      <a-button 
      @click="handleAdd" 
      type="primary" 
      icon="plus"
      >新增设备</a-button>
      <a-dropdown v-if="selectedRowKeys.length > 0">
        <a-menu slot="overlay">
          <a-menu-item key="1" @click="batchDel"><a-icon type="delete"/>取消分配</a-menu-item>
        </a-menu>
        <a-button style="margin-left: 8px"> 批量操作 <a-icon type="down" /></a-button>
      </a-dropdown>
    </div>

    <!-- table区域-begin -->
    <div>
      <div class="ant-alert ant-alert-info" style="margin-bottom: 16px;">
        <i class="anticon anticon-info-circle ant-alert-icon"></i> 已选择 <a style="font-weight: 600">{{ selectedRowKeys.length }}</a>项
        <a style="margin-left: 24px" @click="onClearSelected">清空</a>
      </div>

      <a-table
        ref="table"
        size="middle"
        :scroll="{x:true}"
        bordered
        rowKey="id"
        :columns="columns"
        :dataSource="dataSource"
        :pagination="ipagination"
        :loading="loading"
        :rowSelection="{selectedRowKeys: selectedRowKeys, onChange: onSelectChange}"
        class="j-table-force-nowrap"
        @change="handleTableChange">

        <template slot="htmlSlot" slot-scope="text">
          <div v-html="text"></div>
        </template>
        <template slot="imgSlot" slot-scope="text,record">
          <span v-if="!text" style="font-size: 12px;font-style: italic;">无图片</span>
          <img v-else :src="getImgView(text)" :preview="record.id" height="25px" alt="" style="max-width:80px;font-size: 12px;font-style: italic;"/>
        </template>
        <template slot="fileSlot" slot-scope="text">
          <span v-if="!text" style="font-size: 12px;font-style: italic;">无文件</span>
          <a-button
            v-else
            :ghost="true"
            type="primary"
            icon="download"
            size="small"
            @click="downloadFile(text)">
            下载
          </a-button>
        </template>

        <span slot="action" slot-scope="text, record">
                <a-popconfirm title="确定取消分配吗?" @confirm="() => handleDelete(record.id)">
                  <a>取消分配</a>
                </a-popconfirm>
        </span>
      </a-table>
    </div>

    <work-center-equipment-modal 
    ref="modalForm" 
    @ok="modalFormOk" 
    :enterpriseId="enterpriseId"
    :equipmentCategoryId="equipmentCategoryId"
    :workCenterEquipIds="workCenterEquipIds"
    :workCenterId="workCenterId"
    >
  </work-center-equipment-modal>
  </a-card>
</template>

<script>

  import '@/assets/less/TableExpand.less'
  import { mixinDevice } from '@/utils/mixin'
  import { JeecgListMixin } from '@/mixins/JeecgListMixin'
  import WorkCenterEquipmentModal from './WorkCenterEquipmentModal'
import { getAction } from '../../../../api/manage'

  export default {
    name: 'WorkCenterEquipmentList',
    mixins:[JeecgListMixin, mixinDevice],
    components: {
      WorkCenterEquipmentModal
    },
    props:{
      workCenterId:{
        type: String,
        default: '',
        required: false
      },
      enterpriseId:{
        type: String,
        default: '',
        required: false
      },
      equipmentCategoryId:{
        type: String,
        default: '',
        required: false
      },
      versionStatus:{
        type: String,
        default: '',
        required: false
      }
    },
    watch:{
      workCenterId:{
        immediate: true,
        handler(val) {
          if(!this.workCenterId){
            this.clearList()
          }else{
            this.queryParam['workCenterId'] = val;
            this.queryParam['delFlag'] = '0';
            this.loadData(1);
            this.selectedRowKeys=[];
          }
        }
      }
    },
    data () {
      return {
        description: 'mom_base_work_center_equipment管理页面',
        // 表头
        columns: [
          {
            title: '#',
            dataIndex: '',
            key:'rowIndex',
            align:"center",
            customRender:function (t,r,index) {
              return parseInt(index)+1;
            }
          },
          {
            title:'设备编号',
            align:"center",
            dataIndex: 'equipmentCode',
            width:200
          },
          {
            title:'设备名称',
            align:"center",
            dataIndex: 'equipmentName',
            width:200
          },
          {
            title:'设备型号',
            align:"center",
            dataIndex: 'equipmentModel',
            width:200
          },
          {
            title:'设备规格',
            align:"center",
            dataIndex: 'equipmentStandard',
            width:200
          },
          {
            title:'设备厂家',
            align:"center",
            dataIndex: 'equipmentManufacturer',
            width:200
          },
          {
            title: '操作',
            dataIndex: 'action',
            align:"center",
            fixed:"right",
            width:147,
            scopedSlots: { customRender: 'action' }
          }
        ],
        url: {
          list: "/base/workCenterEquipment/list",
          delete: "/base/workCenterEquipment/delete",
          deleteBatch: "/base/workCenterEquipment/deleteBatch",
          exportXlsUrl: "/base/workCenterEquipment/exportXls",
          importExcelUrl: "base/workCenterEquipment/importExcel",

        },
        dictOptions:{},
        superFieldList:[],
        workCenterEquipIds:''
      }
    },
    created() {
    this.getSuperFieldList();
    },
    computed: {
      importExcelUrl: function(){
        return `${window._CONFIG['domianURL']}/${this.url.importExcelUrl}`;
      },
    },
    methods: {
      initDictConfig(){
      },
      loadData(arg) {
      if(!this.url.list){
        this.$message.error("请设置url.list属性!")
        return
      }
      //加载数据 若传入参数1则加载第一页的内容
      if (arg === 1) {
        this.ipagination.current = 1;
      }
      var params = this.getQueryParams();//查询条件
      this.loading = true;
      getAction(this.url.list, params).then((res) => {
        if (res.success) {
          //update-begin---author:zhangyafei    Date:20201118  for：适配不分页的数据列表------------
          this.dataSource = res.result.records||res.result;
          this.workCenterEquipIds=this.getEquipIdList(res.result.records)
          if(res.result.total)
          {
            this.ipagination.total = res.result.total;
          }else{
            this.ipagination.total = 0;
          }
          //update-end---author:zhangyafei    Date:20201118  for：适配不分页的数据列表------------
        }else{
          this.$message.warning(res.message)
        }
      }).finally(() => {
        this.loading = false
      })
    },
    getEquipIdList(result){
        var ids = '';
        for(var i=0;i<result.length;i++){
            ids=ids+result[i].equipmentId+","
        }
        return ids;
    },
      getSuperFieldList(){
        let fieldList=[];
        fieldList.push({type:'string',value:'equipmentId',text:'设备id',dictCode:''})
        this.superFieldList = fieldList
      },
      clearList(){
        this.dataSource=[]
        this.selectedRowKeys=[]
        this.ipagination.current = 1
      },
    },
  }
</script>
<style scoped>
  @import '~@assets/less/common.less';
</style>